#
# Copyright Michael Orlitzky
#
# http://michael.orlitzky.com/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# http://www.fsf.org/licensing/licenses/gpl.html
#

require 'test/unit'
require 'src/websites/motherless'

class MotherlessTest < Test::Unit::TestCase

  def test_owns_motherless_urls    
    assert(Motherless.owns_url?('http://motherless.com/C1D5A7A'))
    assert(Motherless.owns_url?('http://www.motherless.com/C1D5960'))
  end

  
  def test_doesnt_own_redtube_urls
    assert(!Motherless.owns_url?('http://www.redtube.com/6807'))
    assert(!Motherless.owns_url?('www.redtube.com/6807'))
    assert(!Motherless.owns_url?('http://redtube.com/6807'))
    assert(!Motherless.owns_url?('redtube.com/6807'))
  end


  def test_doesnt_own_howcast_urls
    assert(!Motherless.owns_url?('http://www.howcast.com/videos/6807-2twr'))
    assert(!Motherless.owns_url?('www.howcast.com/videos/6807-2dgfdg'))
    assert(!Motherless.owns_url?('http://howcast.com/videos/6807-cse'))
    assert(!Motherless.owns_url?('howcast.com/videos/6807-asdgasd'))
  end

  
  def test_doesnt_own_misc_urls
    assert(!Motherless.owns_url?('http://www.bliptv.com/123456'))
  end


  def test_parse_video_url
    ml = Motherless.new(nil)

    page_data = nil

    # First Fixture
    
    File.open('test/fixtures/motherless/C1D5960.html') do |f|
      page_data = f.read
    end

    test_result = ml.send('parse_video_url', page_data)
    assert_equal('http://members.motherless.com/movies/C1D5960-204299206.flv', test_result)

    
    # Second Fixture
    
    File.open('test/fixtures/motherless/C1CDA5D.html') do |f|
      page_data = f.read
    end

    test_result = ml.send('parse_video_url', page_data)
    assert_equal('http://members.motherless.com/movies/C1CDA5D-204266691.flv', test_result)    
  end

end
